import React, { CSSProperties } from 'react';
import Player, { IPlayerOptions } from 'xgplayer';
interface PlayerProps extends Player {
    currentVideoIndex?: number;
    video?: {
        duration: number;
    };
    on: (eventName: string | symbol, listener: (...args: any[]) => void) => this;
    off: (eventName: string | symbol, listener: (...args: any[]) => void) => this;
    emit: (eventName: string | symbol, ...args: any[]) => boolean;
}
/** 清晰度视频项目,name 为清晰度,url 为视频源 */
export interface DefinitionItemProps {
    name: string;
    url: string;
}
/** 视频属性配置，继承 xgplayer 配置属性 */
interface VideoProps extends Omit<IPlayerOptions, 'url' | 'loop'> {
    /** 唯一id值 */
    id: string;
    /** 视频路径数组 */
    videoUrls: string[];
    /** 清晰度视频数组,顺序应与 videoUrls 保持一致 */
    definitionList?: DefinitionItemProps[][];
    /** 是否循环播放(多视频只支持循环播放) */
    isLoop?: boolean;
    /** 是否可见 */
    visible?: boolean;
    /** 是否静音播放 */
    muted?: boolean;
    /** 初始化显示首帧 */
    videoInit?: boolean;
    /** 是否允许记忆播放 */
    enableMemory?: boolean;
    /** 记忆提示文字展示时长(s) */
    lastPlayTimeHideDelay?: number;
    /** 手动控制当前播放集数 */
    currentIndex?: number;
    setCurrentIndex?: (currentIndex: number) => void;
    style?: CSSProperties;
    className?: string;
}
declare const _default: React.ForwardRefExoticComponent<VideoProps & React.RefAttributes<PlayerProps>>;
export default _default;
